function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? Object(arguments[i]) : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import { isDarkMode, theme } from '@cloudflare/style-const';
import { createStyledComponent } from '@cloudflare/style-container';
import { Span, Label } from '@cloudflare/elements';
const size = 16;
const lightSvgs = {
  encodedCheck: `url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='${size}' height='${size}' viewBox='0 0 ${size} ${size}' %3E%3Cg %3E%3Cg fill='${theme.colors.gray[3].replace('#', '%23')}' %3E%3Cpath d='M0,0 L16,0 L16,16 L0,16 L0,0 Z M14,4.57911065 L12.4208893,3 L6.26344364,9.1582213 L3.57911065,6.47388831 L2,8.05222337 L6.26344364,12.315667 L14,4.57911065 Z'/%3E%3C/g%3E%3C/g%3E%3C/svg%3E")`,
  encodedIndeterminate: `url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='${size}' height='${size}' viewBox='0 0 ${size} ${size}' %3E%3Cg %3E%3Cg fill='%23a692ac' %3E%3Cpath d='M0,0 L16,0 L16,16 L0,16 L0,0 Z M2,7 L2,9 L14,9 L14,7 L2,7 Z'/%3E%3C/g%3E%3C/g%3E%3C/svg%3E")`
};
const darkSvgs = {
  encodedCheck: `url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='${size}' height='${size}' viewBox='0 0 ${size} ${size}' %3E%3Cg %3E%3Cg fill='${theme.colors.gray[6].replace('#', '%23')}' %3E%3Cpath d='M0,0 L16,0 L16,16 L0,16 L0,0 Z M14,4.57911065 L12.4208893,3 L6.26344364,9.1582213 L3.57911065,6.47388831 L2,8.05222337 L6.26344364,12.315667 L14,4.57911065 Z'/%3E%3C/g%3E%3C/g%3E%3C/svg%3E")`,
  encodedIndeterminate: `url("data:image/svg+xml,%3Csvg xmlns='http://www.w3.org/2000/svg' width='${size}' height='${size}' viewBox='0 0 ${size} ${size}' %3E%3Cg %3E%3Cg fill='${theme.colors.gray[6].replace('#', '%23')}' %3E%3Cpath d='M0,0 L16,0 L16,16 L0,16 L0,0 Z M2,7 L2,9 L14,9 L14,7 L2,7 Z'/%3E%3C/g%3E%3C/g%3E%3C/svg%3E")`
};
const CheckboxInput = createStyledComponent(({
  theme,
  checked,
  invalid,
  indeterminate,
  disabled
}) => {
  const svgs = isDarkMode() ? darkSvgs : lightSvgs;
  return _objectSpread({
    appearance: 'none',
    '-webkit-appearance': 'none',
    width: `${size}px`,
    height: `${size}px`,
    cursor: disabled ? 'default' : 'pointer',
    position: 'relative',
    overflow: 'hidden'
  }, theme.mixins.focus({
    invalid,
    border: true
  }), theme.mixins.input({
    invalid,
    radius: '5px',
    disabled
  }), {
    marginRight: 3,
    marginLeft: 0,
    backgroundPosition: '-1px 0',
    backgroundColor: disabled ? theme.colors.gray[8] : isDarkMode() ? theme.colors.white : theme.colors.background,
    backgroundImage: indeterminate ? svgs.encodedIndeterminate : checked ? svgs.encodedCheck : 'none'
  });
}, 'input');

function Checkbox(_ref) {
  let id = _ref.id,
      name = _ref.name,
      className = _ref.className,
      _ref$indeterminate = _ref.indeterminate,
      indeterminate = _ref$indeterminate === void 0 ? false : _ref$indeterminate,
      checked = _ref.checked,
      value = _ref.value,
      onChange = _ref.onChange,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      testId = _ref.testId,
      label = _ref.label,
      invalid = _ref.invalid,
      noLabel = _ref.noLabel,
      _ref$spacing = _ref.spacing,
      spacing = _ref$spacing === void 0 ? 2 : _ref$spacing,
      unwrap = _ref.unwrap,
      labelProps = _objectWithoutProperties(_ref, ["id", "name", "className", "indeterminate", "checked", "value", "onChange", "disabled", "testId", "label", "invalid", "noLabel", "spacing", "unwrap"]);

  let checkbox = /*#__PURE__*/React.createElement(CheckboxInput, {
    type: "checkbox",
    name: name,
    id: id,
    checked: checked,
    disabled: disabled,
    invalid: invalid,
    onChange: onChange,
    indeterminate: indeterminate,
    className: className,
    "data-testid": testId,
    value: value
  });
  checkbox = unwrap ? checkbox : /*#__PURE__*/React.createElement("div", null, checkbox);
  return noLabel ? checkbox :
  /*#__PURE__*/
  // @ts-ignore
  React.createElement(Label, _extends({
    display: "flex",
    alignItems: "center",
    cursor: disabled ? 'not-allowed' : 'pointer',
    opacity: disabled ? 0.5 : 1,
    m: 0,
    fontSize: "inherit",
    lineHeight: "1",
    minHeight: "auto",
    className: noLabel ? undefined : className
  }, labelProps), checkbox, label && /*#__PURE__*/React.createElement(Span, {
    fontSize: 2,
    ml: spacing,
    mr: 0,
    my: 0
  }, label));
}

export default Checkbox;